==> nextcloud-30.0.13.tgz: nextcloud/apps/systemtags/l10n/ug.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "سىستېما بەلگىسى%1 $ s قوشۇلدى",
    "Added system tag {systemtag}" : "سىستېما بەلگىسى {systemtag} added قوشۇلدى",
    "Added system tag %1$s" : "سىستېما بەلگىسى%1 $ s قوشۇلدى",
    "%1$s added system tag %2$s" : "%1 $ s سىستېما بەلگىسى%2 $ s",
    "{actor} added system tag {systemtag}" : "{actor} قوشۇلغان سىستېما بەلگىسى {systemtag}",
    "System tag %1$s removed by the system" : "سىستېما بەلگىسى%1 $ s سىستېما تەرىپىدىن چىقىرىۋېتىلدى",
    "Removed system tag {systemtag}" : "چىقىرىۋېتىلگەن سىستېما بەلگىسى {systemtag}",
    "Removed system tag %1$s" : "چىقىرىۋېتىلگەن سىستېما بەلگىسى%1 $ s",
    "%1$s removed system tag %2$s" : "%1 $ s ئۆچۈرۈلگەن سىستېما بەلگىسى%2 $ s",
    "{actor} removed system tag {systemtag}" : "{actor} ئۆچۈرۈلگەن سىستېما بەلگىسى {systemtag}",
    "You created system tag %1$s" : "سىستېما بەلگىسى%1 $ s نى قۇردىڭىز",
    "You created system tag {systemtag}" : "سىستېما بەلگىسى {systemtag} created قۇردىڭىز",
    "%1$s created system tag %2$s" : "%1 $ s سىستېما بەلگىسى%2 $ s",
    "{actor} created system tag {systemtag}" : "{actor} سىستېما بەلگىسى {systemtag}",
    "You deleted system tag %1$s" : "سىستېما بەلگىسىنى%1 $ s ئۆچۈردىڭىز",
    "You deleted system tag {systemtag}" : "سىستېما بەلگىسى {systemtag} نى ئۆچۈردىڭىز",
    "%1$s deleted system tag %2$s" : "%1 $ s ئۆچۈرۈلگەن سىستېما بەلگىسى%2 $ s",
    "{actor} deleted system tag {systemtag}" : "{actor} ئۆچۈرۈلگەن سىستېما بەلگىسى {systemtag}",
    "You updated system tag %2$s to %1$s" : "سىستېما بەلگىسىنى%2 $ s دىن%1 $ s غا يېڭىلىدىڭىز",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "سىستېما بەلگىسى {oldsystemtag} نى {newsystemtag} غا يېڭىلىدىڭىز",
    "%1$s updated system tag %3$s to %2$s" : "%1 $ s يېڭىلانغان سىستېما بەلگىسى%3 $ s دىن%2 $ s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} يېڭىلانغان سىستېما بەلگىسى {oldsystemtag} دىن {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "سىستېما بەلگىسى%2 $ s سىستېما تەرىپىدىن%1 $ s غا قوشۇلدى",
    "System tag {systemtag} was added to {file} by the system" : "سىستېما بەلگىسى {systemtag} سىستېما تەرىپىدىن {file} گە قوشۇلدى",
    "You added system tag %2$s to %1$s" : "سىستېما بەلگىسى%2 $ s نى%1 $ s غا قوشتىڭىز",
    "You added system tag {systemtag} to {file}" : "{file} گە سىستېما بەلگىسى {systemtag} نى قوشتىڭىز",
    "%1$s added system tag %3$s to %2$s" : "%1 $ s قوشۇلغان سىستېما بەلگىسى%3 $ s دىن%2 $ s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} {file} بەلگىسىگە سىستېما بەلگىسى {systemtag} قوشۇلدى",
    "System tag %2$s was removed from %1$s by the system" : "سىستېما بەلگىسى%2 $ s سىستېما تەرىپىدىن%1 $ s دىن چىقىرىۋېتىلدى",
    "System tag {systemtag} was removed from {file} by the system" : "سىستېما بەلگىسى {systemtag} سىستېما تەرىپىدىن {file} دىن ئۆچۈرۈلدى",
    "You removed system tag %2$s from %1$s" : "سىستېما بەلگىسىنى%1 $ s دىن ئۆچۈردىڭىز",
    "You removed system tag {systemtag} from {file}" : "سىستېما بەلگىسى {systemtag} نى {file} ئۆچۈردىڭىز",
    "%1$s removed system tag %3$s from %2$s" : "%1 $ s سىستېما بەلگىسى%2 $ s دىن%3 $ s چىقىرىۋېتىلدى",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} {file} دىن سىستېما بەلگىسى {systemtag} نى ئېلىۋەتتى",
    "%s (restricted)" : "% s (چەكلەنگەن)",
    "%s (invisible)" : "% s (كۆرۈنمەيدۇ)",
    "<strong>System tags</strong> for a file have been modified" : "ھۆججەت ئۈچۈن <strong> سىستېما بەلگىسى </ strong> ئۆزگەرتىلدى",
    "Files" : "ھۆججەتلەر",
    "Tags" : "بەلگەلەر",
    "All tagged %s …" : "بارلىق خەتكۈچ% s…",
    "tagged %s" : "خەتكۈچ% s",
    "Collaborative tags" : "ھەمكارلىق بەلگىسى",
    "Collaborative tagging functionality which shares tags among people." : "كىشىلەر ئارىسىدا بەلگە ھەمبەھىرلىنىدىغان ھەمكارلىق بەلگە ئىقتىدارى.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "كىشىلەر ئارىسىدا بەلگە ھەمبەھىرلىنىدىغان ھەمكارلىق بەلگە ئىقتىدارى. كوماندىلار ئۈچۈن ناھايىتى ياخشى.\n\t(ئەگەر سىز كۆپ ئىجارىگە بېرىلگەن قاچىلاش تەمىنلىگۈچى بولسىڭىز ، خەتكۈچ ئورتاقلاشقانلىقتىن بۇ ئەپنى توختىتىش تەۋسىيە قىلىنىدۇ.)",
    "Public" : "جامائەت",
    "Restricted" : "چەكلەنگەن",
    "Invisible" : "كۆرۈنمەيدۇ",
    "Created tag" : "خەتكۈچ قۇرۇلدى",
    "Failed to create tag" : "بەلگە قۇرالمىدى",
    "Updated tag" : "خەتكۈچ يېڭىلاندى",
    "Failed to update tag" : "خەتكۈچ يېڭىلانمىدى",
    "Deleted tag" : "ئۆچۈرۈلگەن خەتكۈچ",
    "Failed to delete tag" : "خەتكۈچنى ئۆچۈرەلمىدى",
    "Create or edit tags" : "خەتكۈچ قۇرۇش ياكى تەھرىرلەش",
    "Search for a tag to edit" : "تەھرىرلەش ئۈچۈن بەلگە ئىزدەڭ",
    "Collaborative tags …" : "ھەمكارلىق خەتكۈچلىرى…",
    "No tags to select" : "تاللايدىغان بەلگە يوق",
    "Tag name" : "خەتكۈچ ئىسمى",
    "Tag level" : "خەتكۈچ دەرىجىسى",
    "Create" : "قۇر",
    "Update" : "يېڭىلا",
    "Delete" : "ئۆچۈر",
    "Reset" : "ئەسلىگە قايتۇرۇش",
    "Loading …" : "Loading…",
    "{displayName} (hidden)" : "{displayName} (يوشۇرۇن)",
    "{displayName} (restricted)" : "{displayName} (چەكلەنگەن)",
    "Failed to apply tags changes" : "خەتكۈچ ئۆزگەرتىش قوللانمىدى",
    "File tags modification canceled" : "ھۆججەت خەتكۈچلىرىنى ئۆزگەرتىش ئەمەلدىن قالدۇرۇلدى",
    "Manage tags" : "خەتكۈچلەرنى باشقۇرۇش",
    "Applying tags changes…" : "خەتكۈچ ئۆزگەرتىش…",
    "Search or create tag" : "بەلگە ئىزدەش ياكى قۇرۇش",
    "Select or create tags to apply to all selected files" : "بارلىق تاللانغان ھۆججەتلەرگە ماس كېلىدىغان بەلگىلەرنى تاللاڭ ياكى قۇرالايسىز",
    "Cancel" : "بىكار قىلىش",
    "Apply changes" : "ئۆزگەرتىشلەرنى ئىشلىتىڭ",
    "Failed to load tags" : "خەتكۈچلەرنى يۈكلىيەلمىدى",
    "Failed to load selected tags" : "تاللانغان خەتكۈچلەرنى يۈكلىيەلمىدى",
    "Failed to select tag" : "خەتكۈچنى تاللىيالمىدى",
    "Loading collaborative tags …" : "ھەمكارلىق خەتكۈچلىرىنى يۈكلەۋاتىدۇ…",
    "Search or create collaborative tags" : "ھەمكارلىق خەتكۈچلىرىنى ئىزدەڭ ياكى قۇرۇڭ",
    "No tags to select, type to create a new tag" : "تاللايدىغان بەلگە يوق ، يېڭى خەتكۈچ قۇرۇش ئۈچۈن كىرگۈزۈڭ",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "ھەمكارلىق بەلگىسى بارلىق ئىشلەتكۈچىلەر ئۈچۈن تەمىنلىنىدۇ. چەكلەنگەن بەلگىلەرنى ئىشلەتكۈچىلەر كۆرەلەيدۇ ، ئەمما ئۇلار بەلگىلىمەيدۇ. كۆرۈنمەيدىغان بەلگىلەر ئىچكى ئىشلىتىشكە ئىشلىتىلىدۇ ، چۈنكى ئىشلەتكۈچىلەر ئۇلارنى كۆرەلمەيدۇ ياكى تەقسىملىيەلمەيدۇ.",
    "Assigned collaborative tags" : "ھەمكارلىق خەتكۈچلىرى",
    "Open in Files" : "ھۆججەتلەرنى ئېچىڭ",
    "List of tags and their associated files and folders." : "خەتكۈچ ۋە ئۇلارنىڭ مۇناسىۋەتلىك ھۆججەتلىرى ۋە ھۆججەت قىسقۇچلىرى.",
    "No tags found" : "خەتكۈچ تېپىلمىدى",
    "Tags you have created will show up here." : "سىز قۇرغان خەتكۈچلەر بۇ يەردە كۆرۈنىدۇ.",
    "Failed to load tag" : "خەتكۈچ يۈكلەنمىدى",
    "Failed to load last used tags" : "ئاخىرقى ئىشلىتىلگەن خەتكۈچلەرنى يۈكلىيەلمىدى",
    "Missing \"Content-Location\" header" : "«مەزمۇن-ئورۇن» ماۋزۇسى يوقاپ كەتتى",
    "A tag with the same name already exists" : "ئوخشاش ئىسىمدىكى بەلگە ئاللىبۇرۇن مەۋجۇت",
    "Failed to load tags for file" : "ھۆججەتنىڭ خەتكۈچلىرىنى يۈكلىيەلمىدى",
    "Failed to set tag for file" : "ھۆججەتكە بەلگە بەلگىلەش مەغلۇپ بولدى",
    "Failed to delete tag for file" : "ھۆججەتنىڭ بەلگىسىنى ئۆچۈرەلمىدى"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.9.tgz: nextcloud/apps/systemtags/l10n/ug.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "سىستېما بەلگىسى%1 $ s قوشۇلدى",
    "Added system tag {systemtag}" : "سىستېما بەلگىسى {systemtag} added قوشۇلدى",
    "Added system tag %1$s" : "سىستېما بەلگىسى%1 $ s قوشۇلدى",
    "%1$s added system tag %2$s" : "%1 $ s سىستېما بەلگىسى%2 $ s",
    "{actor} added system tag {systemtag}" : "{actor} قوشۇلغان سىستېما بەلگىسى {systemtag}",
    "System tag %1$s removed by the system" : "سىستېما بەلگىسى%1 $ s سىستېما تەرىپىدىن چىقىرىۋېتىلدى",
    "Removed system tag {systemtag}" : "چىقىرىۋېتىلگەن سىستېما بەلگىسى {systemtag}",
    "Removed system tag %1$s" : "چىقىرىۋېتىلگەن سىستېما بەلگىسى%1 $ s",
    "%1$s removed system tag %2$s" : "%1 $ s ئۆچۈرۈلگەن سىستېما بەلگىسى%2 $ s",
    "{actor} removed system tag {systemtag}" : "{actor} ئۆچۈرۈلگەن سىستېما بەلگىسى {systemtag}",
    "You created system tag %1$s" : "سىستېما بەلگىسى%1 $ s نى قۇردىڭىز",
    "You created system tag {systemtag}" : "سىستېما بەلگىسى {systemtag} created قۇردىڭىز",
    "%1$s created system tag %2$s" : "%1 $ s سىستېما بەلگىسى%2 $ s",
    "{actor} created system tag {systemtag}" : "{actor} سىستېما بەلگىسى {systemtag}",
    "You deleted system tag %1$s" : "سىستېما بەلگىسىنى%1 $ s ئۆچۈردىڭىز",
    "You deleted system tag {systemtag}" : "سىستېما بەلگىسى {systemtag} نى ئۆچۈردىڭىز",
    "%1$s deleted system tag %2$s" : "%1 $ s ئۆچۈرۈلگەن سىستېما بەلگىسى%2 $ s",
    "{actor} deleted system tag {systemtag}" : "{actor} ئۆچۈرۈلگەن سىستېما بەلگىسى {systemtag}",
    "You updated system tag %2$s to %1$s" : "سىستېما بەلگىسىنى%2 $ s دىن%1 $ s غا يېڭىلىدىڭىز",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "سىستېما بەلگىسى {oldsystemtag} نى {newsystemtag} غا يېڭىلىدىڭىز",
    "%1$s updated system tag %3$s to %2$s" : "%1 $ s يېڭىلانغان سىستېما بەلگىسى%3 $ s دىن%2 $ s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} يېڭىلانغان سىستېما بەلگىسى {oldsystemtag} دىن {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "سىستېما بەلگىسى%2 $ s سىستېما تەرىپىدىن%1 $ s غا قوشۇلدى",
    "System tag {systemtag} was added to {file} by the system" : "سىستېما بەلگىسى {systemtag} سىستېما تەرىپىدىن {file} گە قوشۇلدى",
    "You added system tag %2$s to %1$s" : "سىستېما بەلگىسى%2 $ s نى%1 $ s غا قوشتىڭىز",
    "You added system tag {systemtag} to {file}" : "{file} گە سىستېما بەلگىسى {systemtag} نى قوشتىڭىز",
    "%1$s added system tag %3$s to %2$s" : "%1 $ s قوشۇلغان سىستېما بەلگىسى%3 $ s دىن%2 $ s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} {file} بەلگىسىگە سىستېما بەلگىسى {systemtag} قوشۇلدى",
    "System tag %2$s was removed from %1$s by the system" : "سىستېما بەلگىسى%2 $ s سىستېما تەرىپىدىن%1 $ s دىن چىقىرىۋېتىلدى",
    "System tag {systemtag} was removed from {file} by the system" : "سىستېما بەلگىسى {systemtag} سىستېما تەرىپىدىن {file} دىن ئۆچۈرۈلدى",
    "You removed system tag %2$s from %1$s" : "سىستېما بەلگىسىنى%1 $ s دىن ئۆچۈردىڭىز",
    "You removed system tag {systemtag} from {file}" : "سىستېما بەلگىسى {systemtag} نى {file} ئۆچۈردىڭىز",
    "%1$s removed system tag %3$s from %2$s" : "%1 $ s سىستېما بەلگىسى%2 $ s دىن%3 $ s چىقىرىۋېتىلدى",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} {file} دىن سىستېما بەلگىسى {systemtag} نى ئېلىۋەتتى",
    "%s (restricted)" : "% s (چەكلەنگەن)",
    "%s (invisible)" : "% s (كۆرۈنمەيدۇ)",
    "<strong>System tags</strong> for a file have been modified" : "ھۆججەت ئۈچۈن <strong> سىستېما بەلگىسى </ strong> ئۆزگەرتىلدى",
    "Files" : "ھۆججەتلەر",
    "Tags" : "بەلگەلەر",
    "All tagged %s …" : "بارلىق خەتكۈچ% s…",
    "tagged %s" : "خەتكۈچ% s",
    "Collaborative tags" : "ھەمكارلىق بەلگىسى",
    "Collaborative tagging functionality which shares tags among people." : "كىشىلەر ئارىسىدا بەلگە ھەمبەھىرلىنىدىغان ھەمكارلىق بەلگە ئىقتىدارى.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "كىشىلەر ئارىسىدا بەلگە ھەمبەھىرلىنىدىغان ھەمكارلىق بەلگە ئىقتىدارى. كوماندىلار ئۈچۈن ناھايىتى ياخشى.\n\t(ئەگەر سىز كۆپ ئىجارىگە بېرىلگەن قاچىلاش تەمىنلىگۈچى بولسىڭىز ، خەتكۈچ ئورتاقلاشقانلىقتىن بۇ ئەپنى توختىتىش تەۋسىيە قىلىنىدۇ.)",
    "Public" : "جامائەت",
    "Restricted" : "چەكلەنگەن",
    "Invisible" : "كۆرۈنمەيدۇ",
    "Created tag" : "خەتكۈچ قۇرۇلدى",
    "Failed to create tag" : "بەلگە قۇرالمىدى",
    "Updated tag" : "خەتكۈچ يېڭىلاندى",
    "Failed to update tag" : "خەتكۈچ يېڭىلانمىدى",
    "Deleted tag" : "ئۆچۈرۈلگەن خەتكۈچ",
    "Failed to delete tag" : "خەتكۈچنى ئۆچۈرەلمىدى",
    "Create or edit tags" : "خەتكۈچ قۇرۇش ياكى تەھرىرلەش",
    "Search for a tag to edit" : "تەھرىرلەش ئۈچۈن بەلگە ئىزدەڭ",
    "Collaborative tags …" : "ھەمكارلىق خەتكۈچلىرى…",
    "No tags to select" : "تاللايدىغان بەلگە يوق",
    "Tag name" : "خەتكۈچ ئىسمى",
    "Tag level" : "خەتكۈچ دەرىجىسى",
    "Create" : "قۇر",
    "Update" : "يېڭىلا",
    "Delete" : "ئۆچۈر",
    "Reset" : "ئەسلىگە قايتۇرۇش",
    "Loading …" : "Loading…",
    "{displayName} (hidden)" : "{displayName} (يوشۇرۇن)",
    "{displayName} (restricted)" : "{displayName} (چەكلەنگەن)",
    "Failed to apply tags changes" : "خەتكۈچ ئۆزگەرتىش قوللانمىدى",
    "Manage tags" : "خەتكۈچلەرنى باشقۇرۇش",
    "Applying tags changes…" : "خەتكۈچ ئۆزگەرتىش…",
    "Search or create tag" : "بەلگە ئىزدەش ياكى قۇرۇش",
    "Cancel" : "بىكار قىلىش",
    "Apply" : "ئىلتىماس قىلىڭ",
    "Failed to load tags" : "خەتكۈچلەرنى يۈكلىيەلمىدى",
    "Failed to load selected tags" : "تاللانغان خەتكۈچلەرنى يۈكلىيەلمىدى",
    "Failed to select tag" : "خەتكۈچنى تاللىيالمىدى",
    "Loading collaborative tags …" : "ھەمكارلىق خەتكۈچلىرىنى يۈكلەۋاتىدۇ…",
    "Search or create collaborative tags" : "ھەمكارلىق خەتكۈچلىرىنى ئىزدەڭ ياكى قۇرۇڭ",
    "No tags to select, type to create a new tag" : "تاللايدىغان بەلگە يوق ، يېڭى خەتكۈچ قۇرۇش ئۈچۈن كىرگۈزۈڭ",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "ھەمكارلىق بەلگىسى بارلىق ئىشلەتكۈچىلەر ئۈچۈن تەمىنلىنىدۇ. چەكلەنگەن بەلگىلەرنى ئىشلەتكۈچىلەر كۆرەلەيدۇ ، ئەمما ئۇلار بەلگىلىمەيدۇ. كۆرۈنمەيدىغان بەلگىلەر ئىچكى ئىشلىتىشكە ئىشلىتىلىدۇ ، چۈنكى ئىشلەتكۈچىلەر ئۇلارنى كۆرەلمەيدۇ ياكى تەقسىملىيەلمەيدۇ.",
    "Assigned collaborative tags" : "ھەمكارلىق خەتكۈچلىرى",
    "Open in Files" : "ھۆججەتلەرنى ئېچىڭ",
    "List of tags and their associated files and folders." : "خەتكۈچ ۋە ئۇلارنىڭ مۇناسىۋەتلىك ھۆججەتلىرى ۋە ھۆججەت قىسقۇچلىرى.",
    "No tags found" : "خەتكۈچ تېپىلمىدى",
    "Tags you have created will show up here." : "سىز قۇرغان خەتكۈچلەر بۇ يەردە كۆرۈنىدۇ.",
    "Failed to load tag" : "خەتكۈچ يۈكلەنمىدى",
    "Failed to load last used tags" : "ئاخىرقى ئىشلىتىلگەن خەتكۈچلەرنى يۈكلىيەلمىدى",
    "Missing \"Content-Location\" header" : "«مەزمۇن-ئورۇن» ماۋزۇسى يوقاپ كەتتى",
    "A tag with the same name already exists" : "ئوخشاش ئىسىمدىكى بەلگە ئاللىبۇرۇن مەۋجۇت",
    "Failed to load tags for file" : "ھۆججەتنىڭ خەتكۈچلىرىنى يۈكلىيەلمىدى",
    "Failed to set tag for file" : "ھۆججەتكە بەلگە بەلگىلەش مەغلۇپ بولدى",
    "Failed to delete tag for file" : "ھۆججەتنىڭ بەلگىسىنى ئۆچۈرەلمىدى",
    "File tags modification canceled" : "ھۆججەت خەتكۈچلىرىنى ئۆزگەرتىش ئەمەلدىن قالدۇرۇلدى",
    "Select or create tags to apply to all selected files" : "بارلىق تاللانغان ھۆججەتلەرگە ماس كېلىدىغان بەلگىلەرنى تاللاڭ ياكى قۇرالايسىز",
    "Apply changes" : "ئۆزگەرتىشلەرنى ئىشلىتىڭ"
},
"nplurals=2; plural=(n != 1);");
